@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000,2001 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ def PrintResults(mlist, operation, doc, results, user=None):
     if user:
         # Avoid cross-site scripting attack
         url = '%s/%s' % (mlist.GetScriptURL('options'),
-                         Utils.ObscureEmail(cgi.escape(user)))
+                         Utils.ObscureEmail(Utils.QuoteHyperChars(user)))
         results = results + '<p>Continue to ' + \
                   Link(url, 'edit your personal options').Format() + \
                   '.'
@@ -66,7 +66,7 @@ def main():
         mlist = MailList.MailList(listname, lock=0)
     except Errors.MMListError, e:
         # Avoid cross-site scripting attack
-        safelistname = cgi.escape(listname)
+        safelistname = Utils.QuoteHyperChars(listname)
         doc.AddItem(Header(2, "Error"))
         doc.AddItem(Bold('No such list <em>%s</em>' % safelistname))
         print doc.Format(bgcolor="#ffffff")
@@ -110,7 +110,7 @@ def process_form(mlist, user, doc):
     if not Utils.FindMatchingAddresses(user, mlist.members,
                                        mlist.digest_members):
         # Avoid cross-site scripting attack
-        safeuser = cgi.escape(user)
+        safeuser = Utils.QuoteHyperChars(user)
         PrintResults(mlist, operation, doc, "%s not a member!<p>" % safeuser)
 
     if form.has_key("unsub"):
