@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000,2001 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -45,7 +45,7 @@ def main():
         mlist = MailList.MailList(listname, lock=0)
     except Errors.MMListError, e:
         # Avoid cross-site scripting attacks
-        safelistname = cgi.escape(listname)
+        safelistname = Utils.QuoteHyperChars(listname)
         doc.AddItem(Header(2, "Error"))
         doc.AddItem(Bold('No such list <em>%s</em>' % safelistname))
         print doc.Format(bgcolor="#ffffff")
@@ -118,7 +118,7 @@ def process_form(mlist, doc):
         if not member:
             doc.AddItem(Header(2, "Error"))
             doc.AddItem(Bold("%s has no subscribed addr <i>%s</i>."
-                             % (mlist.real_name, addr)))
+                             % (mlist.real_name, Utils.QuoteHyperChars(addr))))
             doc.AddItem(mlist.GetMailmanFooter())
             print doc.Format(bgcolor="#ffffff")
             return
