@@ -118,7 +118,7 @@ class SecurityManager:
         cookiedata = os.environ.get('HTTP_COOKIE')
         if not cookiedata:
             return 0
-        c = Cookie.Cookie(cookiedata)
+        c = Cookie.Cookie(cookiedata, net_setfunc=lambda x: x)
         if not c.has_key(key):
             return 0
         # Undo the encoding we performed in MakeCookie() above
