@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000,2001 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -422,8 +422,7 @@ def CheckSiteAdminPassword(pw1):
 
 
 def QuoteHyperChars(str):
-    from cgi import escape
-    return escape(str, quote=1)
+    return cgi.escape(str, quote=1)
 
 
 
@@ -631,7 +630,7 @@ def GetRequestURI(fallback=None, escape=1):
     elif os.environ.has_key('SCRIPT_NAME') and os.environ.has_key('PATH_INFO'):
         url = os.environ['SCRIPT_NAME'] + os.environ['PATH_INFO']
     if escape:
-        return cgi.escape(url)
+        return QuoteHyperChars(url)
     return url
 
 
